Convert to linear space
base-set.RdA number given in some logarithmic space can be transformed back to linear space
A call like base(x) <- 10 means that x was provided in decadic logarithm form.
This will adjust x so that it is now in linear space.
Usage
base(x, i = seq_along(x)) <- valueExamples
x <- 2
base(x) <- 10
print(x)
#> [1] 100