Skip to contents

Given a data.frame that should contain a column that assigns a math expression to a name (in row names), this function returns a named character vector with the expressions. The formula column shoul dbe named "formula" (if it exists, only this column will be used). But some other spellings will also work as fallback. As a fallback "value" is acceptable as well, because it makes sense to say "the value of x is 'y/2+1'", even though it is not an atomic value (but an expression).

Usage

formulae(df)

Arguments

df

a data.frame with a "formula" column

Value

character vector with names taken from the row names of df