Construct Code
generate_code.RdInterpret the first argument and generate code in the specified language for the model type.
Details
Whenever the model Model is of type "cme", the LV parameter is
used to determine the actual number of molecules in the
system. Otherwise it is ignored.
Examples
m <- model_from_tsv(uqsa_example("AKAR4"))
o <- as_ode(m)
C <- generate_code(o)
cat(head(C),sep="\n")
#> #include <stdlib.h>
#> #include <math.h>
#> #include <string.h>
#> #include <gsl/gsl_errno.h>
#> #include <gsl/gsl_odeiv2.h>
#> #include <gsl/gsl_math.h>