Skip to contents

This function uses default assumption everywhere and returns a function that will sample from the given model. This funciton will generate code, compile the code, create an ODE solver for it, infer the sampling space from the scale of the parameters, create all necessary functions to move in parameter space (gradients of likelihood and prior), as well as Fisher Information functions.

Usage

high_level_smmala(
  m,
  o = as_ode(m, cla = TRUE),
  ex = experiments(m, o),
  x = values(m$Parameter)
)

Arguments

m

the model's TSV representation read via model_from_tsv

o

(optional) ode representation of m

ex

experiments of m, with simulation instructions for o.

x

initial point of the markov chain, pre in itialized to have the right attributes.

Value

smmala a function of three arguments: p0, N, eps; where p0 is the starting point, N is the desired sample-size, and eps is the step size. This function has an attribute called "init", with a pre-initialized starting point.