LOG2 parameter mapping used by the MCMC module
log2ParMap.RdThis map is used by the simulator to transform sampling variables into ODE-model porameters.
log2ParMap.RdThis map is used by the simulator to transform sampling variables into ODE-model porameters.