Returns only the names in a reaction formula
onlyNames.RdThis is the companion function to onlyCoefficients. It returns the names of reactants, without the stoichiometry.
Examples
print(onlyNames("12 A"))
#> [[1]]
#> [1] " A"
#>
onlyNames.RdThis is the companion function to onlyCoefficients. It returns the names of reactants, without the stoichiometry.
print(onlyNames("12 A"))
#> [[1]]
#> [1] " A"
#>