Skip to contents

This information printed on screen omits the deatls about the interactions, only the lengths of the vectors included in the data structure CME.

Usage

# S3 method for cme
print(cmeModel)

Arguments

cmeModel

a model created by as_cme

Value

Nil

Examples

f <- uqsa_example("AKAR4")
m <- model_from_tsv(f)
cmeModel <- as_cme(m)
print(cmeModel)
#>                       Name : AKAR4
#> 
#> 
#>  Number of state variables : 4
#>       Number of parameters : 3
#>          Number of outputs : 1
#>        Number of constants : 0