Skip to contents

This function will display the difference between the posterior and prior by plotting the posterior as shaded density plots and the prior as contour lines of level sets. If the two are identical, the lines will be invisible as they blend into the density plot. Otherwise the contour lines will show up as a distinct feature.

Usage

showPosterior(posterior, prior, lower.panel = lp, upper.panel = up, ...)

Arguments

posterior

a matrix, each row is a sample member

prior

a matrix of the same size as the posterior

lower.panel

a lower panel plot function with a default that shows correlation values (color coded)

upper.panel

an upper panel plot function which defaults to shaded density plots of the posterior with contour lines for the prior distribution.

Value

pairs plot object