Subset simulations with preserved class
sub-.simulation.RdThe normal list subset operation would drop the class from the simulation object (which is fine in theory). With this override, the class is preserved.
sub-.simulation.RdThe normal list subset operation would drop the class from the simulation object (which is fine in theory). With this override, the class is preserved.