Converts a unit to a string that works as an identifier
unit.id.Rd
Some formats require a name for a unit definition. This functions
creates a name from a unit, converting math/symbols to text. The
returned value should work as an SBML unit id.
Usage
unit.id(unit.str, verbose =FALSE)
Arguments
unit.str
the original string representation of that unit
verbose
logical switch: if TRUE, the name will be printed.