find unit category
unit.kind.RdThis function reads a unit, without SI prefix, and returns a string from a smaller subset of unit kinds, similar to what is defined in SBML. This normalizes the various ways to write the same unit: "meter", "m" and "metre".
Value
normalized category name of the unit kind: litre, mole, metre, kilogram, gram, ampere, candela, second, kelvin, hour, molarity, dimensionless. defaults to dimensionless.
Examples
print(unit.kind("meter"))
#> Error in unit.kind("meter"): could not find function "unit.kind"