Unit scale from SI prefix
unit.scale.RdThis function reads a prefix from a string and returns the exponent (base-10) that this prefix represents.
Examples
print(unit.scale("M"))
#> Error in unit.scale("M"): could not find function "unit.scale"
unit.scale.RdThis function reads a prefix from a string and returns the exponent (base-10) that this prefix represents.
print(unit.scale("M"))
#> Error in unit.scale("M"): could not find function "unit.scale"