Get units from a data.frame column
units_from_table.RdGiven a data.frame this funciton retrieves the strings in the unit column named: unit, Unit, units (partial matching disregarding capitalization).
Details
The returned value uses the row names of the data.frame as names of the character vector of units.
Examples
m <- model_from_tsv(uqsa_example("AKAP79"))
u <- units_from_table(m$Compound)