Interpret a model as an ODE
as_ode.RdThis function accepts a list generated from a collection of TSV files (or a similar format) and interprets the contents as an ordinary differential equation (ODE).
Usage
as_ode(m, cla = requireNamespace("pracma"))Arguments
- m
a list of data.frames, each corresponding to a TSV file or sheet in a spreadsheet.
- cla
a Boolean value indicating whether conservation law analysis should be performed.
Value
a list that contains a summary of this model interpreted as
an ODE, crucially, the list contains the element vf, the
right-hand-side (vector field) of the ODE, this is the main
result of this function.
Details
The argument m can be obtained via model_from_tsv().
It has the components:
m$Constantm$Parameterm$Inputm$Expressionm$Compoundm$Reactionm$Experiment
There can be additional components describing measured data for this model.