Convert to linear space
base-set.RdA number given in some logarithmic space can be transformed back to linear space
A call like base(x) <- 10 means that x was provided in decadic logarithm form.
This will adjust x so that it is now in linear space.
Usage
base(x, i = seq_along(x)) <- valueArguments
- x
a numeric vector
- i
a subset of values in x, defaults to all values of x
- value
the base of the logarithm x was provided in
Examples
x <- 1
base(x) <- 10
#> Error in base(x) <- 10: could not find function "base<-"
print(x)
#> [1] 1