Add information about the model's C code
c_path-set.RdAdds the location of the model's C code (a file). The model is typically a list of named numeric and named character vectors, which describe the (interpreted) model.
Usage
c_path(o) <- valuec_path-set.RdAdds the location of the model's C code (a file). The model is typically a list of named numeric and named character vectors, which describe the (interpreted) model.
c_path(o) <- value