ABC acceptance of currently sampled values given old data (Prior)
checkFitWithPreviousExperiments.RdThe prior probability density model using copulas and vines is not perfect, so values sampled from an imperfect prior estimate can be checked against old data.
Examples
if (FALSE) { # \dontrun{
posterior <- ABCMCMC(...)
passed <- checkFitWithPreviousExperiments(posterior$draws, objFunc, delta=0.5)
posterior$draws <- passed
} # }