Skip to contents

When indexing a matrix, rownames are lost. This function will return a column of a matrix, as a vector (dropping rank so to speak), but the vector will retain the rownames of the matrix

Usage

column(m, j = 1)

Arguments

m

a matrix

j

a column index

Value

a named vector