Reduce the size of the system
conservation_law_analysis.RdGiven a stoichiometric matrix, this function performs model reduction via linear algebra operations, with pracma::null.
conservation_law_analysis.RdGiven a stoichiometric matrix, this function performs model reduction via linear algebra operations, with pracma::null.