Skip to contents

This function accepts the model obtained via model_fromt_tsv or a similar function. It finds the data tables for this model (if any are present), and finds the simulation instructions to reproduce these data sets using the model.

Usage

experiments(m, o)

Arguments

m

the model (with data), as obtained via model_from_tsv(), or similar.

o

the ode derived from m

Value

a list of simulation instructions

Details

This function requires that the files the model is stored as contains measurements (data) that can be interpreted fairly easily. Each data file needs columns that are named like the observable quantities listed in the Output table.

If the data is very indirectly related to the model, then we don't interpret the data files themselves and the user needs to write a specialized likelihood function to relate the raw data in the files with something that the model does. In such cases, don't use this function.

The instructions must be organised in a table called Experiment(s).