Skip to contents

For small samples, it is better to load the entire sample and analyse it in full. This function is intended for samples that are so big that they challenge the memory of the machine.

Usage

gatherReplicas(files)

Arguments

files

a list of file names

Value

a matrix of sampled points, all with the same temperature

Details

This function is quicker if you have used trivial parallelism, without mpi communication between the ranks (or another method of obtaining several replicas, like forking or sequetial reprtition).

This function assumes that each supplied RDS file contains a matrix of model MCMC parameters. The returned value X will be the rbind of all the smaller x contained in the individual files. The value X will have several attributes attached to it:

  • logLikelihood: log(likelihood(X[i,])), one value per row of X

  • stepSize: the MCMC step size used in each given file#'