Write R code
generateRCode.RdThis function expects a list of character vectors, as returned by
SBtabVFGEN::sbtab_to_vfgen. This list describes an ODE model
(initial values, default parameters, transformation events, output
functions). This function uses this information, calculates
Jacobians via Ryacas and returns a character vector with R source
code for the deSolve package.
Arguments
- odeModel
a list, as returned from
SBtabVFGEN::sbtab_to_vfgen()