Skip to contents

Extracts the FisherInformation values from the simulations attribute of the parMCMC argument, requires:

  • parMCMC has simulations attribute

  • simulations list includes Fisher-Information values

Usage

gllf(parMapJac = log10ParMapJac)

Arguments

parMCMC

a numeric vector, with attributes for MCMC, specifically smmala

Value

a numeric vector: grad(log(likelihood(data|parMCMC)))

Details

This function will take the log-likelihood gradient values claculated by the ode solver in this package, and return the sum of those vectors over all experiments. The gll-value the simulator returns is calculated with the assumption of a normal distribution on measurement errors.

This function uses the log10ParMapJac(parMCMC) function by default, which assumes that sampling takes place in logarithmic space with base 10.

Like ll this function does almost no work, it merely sums up the gradient values calculated during simulation, but it also performs a transformation of the gradient vector, taking the parameter-mapping between the sampling-space and model-parameter-space into account.