High Level SMMALA function
high_level_smmala.RdThis function uses default assumption everywhere and returns a function that will sample from the given model. This funciton will generate code, compile the code, create an ODE solver for it, infer the sampling space from the scale of the parameters, create all necessary functions to move in parameter space (gradients of likelihood and prior), as well as Fisher Information functions.
Usage
high_level_smmala(
m,
o = as_ode(m, cla = TRUE),
ex = experiments(m, o),
x = values(m$Parameter)
)