Skip to contents

This function returns the molecule count apart from LV. This number must be multiplied by Avogadro's constant and volume.

Usage

initialCount(m)

Arguments

m

the model data.frames obtained from model_from_tsv

Value

numeric vector or character vector, depending on how the initial concentration was provided

Details

The multiplication with LV isn't done here, because this allows the user to change the volume of the system in the C-file, without re-generating it from a model. The same c-file can be re-used that way.