Initial count of reacting Compounds
initialCount.RdThis function returns the molecule count apart from LV. This number must be multiplied by Avogadro's constant and volume.
Arguments
- m
the model data.frames obtained from model_from_tsv
initialCount.RdThis function returns the molecule count apart from LV. This number must be multiplied by Avogadro's constant and volume.
the model data.frames obtained from model_from_tsv