NATURAL LOG parameter mapping used by the MCMC module
logParMap.RdThis map is used by the simulator to transform sampling variables into ODE-model porameters.
logParMap.RdThis map is used by the simulator to transform sampling variables into ODE-model porameters.