makeGillespieModel interprets the provided SBtab file as a stochastic model
makeGillespieModel.RdThe SBtab file is assumed to describe a reaction network. The systems biology information is assumed to be concentrations and rate coefficients.
Arguments
- m
list of data.frames, obtained via
model_from_tsv()- LV
Avogadro's constant L multiplied by the system's volume V.