Skip to contents

the returned objective function has only one argument: the ABC variables that shall be mapped to ODE-model parameters.

Usage

makeObjective(experiments, simulate, distance = defaultDistance)

Arguments

experiments

a list of simulation experiments

simulate

closure that simulates the model

distance

a function that calculates ABC scores (distance between data and simulations)

Value

an objective function

Details

The user supplied distance function should accept three arguments: distance(SIM, DATA, STDV), all three matrices. SIM is the model output (simulation), DATA is the measured data, while STDV represents the standard error of that measurement. All three have the same size: N×M, where N is the number of observables (outputs), and M is th enumber of measurement time-points (length of the time-series).