Initialize the Markov chain
mcmc_init.RdThis function must append all required attributes to the MCMC varible, for the Markov chain to update correctly.
Arguments
- beta
inverse temperature for the Markov chain (parallel tempering)
- parMCMC
a plain starting value for the Markov chain
- logLikelihood
a function that maps simulations to logLikelihood values
- gradLogLikelihood
the gradient function of the logLikelihood (optional) -- only if the algorithm requires it
- fisherInformation
a function that calculates the Fisher Information matrix