The MPI version of the mcmc function
mcmc_mpi.Rdthis version of the MCMC function returns a Markov chain closure
that assumes that it is bein run in an MPI context: R was launched
using runmpi and the Rmpi package is installed. The chains shall
communicate using the provided comm.
Arguments
- update
an update function
- comm
an mpi comm which this function will use for send/receive operations
- swapDelay
swaps will be attempted every 2*swapDelay+1 iterations deprecated