model_from_tsv loads the content from a series of tsv files
model_from_tsv.RdThe argument can be either a series of tsv file-names, or a directory with tsv files. If it is a directory, all tsv files therein wil be used.
model_from_tsv.RdThe argument can be either a series of tsv file-names, or a directory with tsv files. If it is a directory, all tsv files therein wil be used.