This function calculates the conversion from moles to particle counts
moleCountConversion.RdGiven some molar quantity with a unit (character vector), this function calculates a conversion factor based on the SI prefixes used, as well as what the exponent of LV (Avogadro's constant * Volume) applies in this case.