Reverse look-up of method name from key
name_method.RdThese are the methods in the gsl library (documented in the official documentation), but in reverse order, as they are approximately ordered by complexity, with more complex methods usually being better (but slower).
Usage
name_method(key = seq(0, 10))Details
It is therefore a reasonable approach to try methods from the more complex end of the list first and try the next method if the solutions are too slow. But we need to check the accuracy/stability of the result. The mapping between method names and keys:
The returned value is an integer index.
Examples
print(name_method())
#> [1] "msbdf" "msadams" "bsimp" "rk4imp" "rk2imp" "rk1imp" "rk8pd"
#> [8] "rkck" "rkf45" "rk4" "rk2"