Skip to contents

Given parameters of a reaction kinetic coefficient model with concentrations as state variables, this function returns the parameters of the stochastic version of that model

Usage

parameterConversion(unit, reactants, products, kinetic.law)

Arguments

unit

of the kinetic parameters (a character vector), named.

reactants

a list of the stoichiometric constants of each reaction, a list of integer vectors

products

a list of the stoichiometric constants of each reaction, a list of integer vectors

Value

a vector of parameter conversion factors

Details

For this function, it is important that "2 A -> B" is not written as "A + A -> B" (this may be fixed later).