rCopulaPrior returns a function that generates random values from the copula model
rCopulaPrior.RdThe returned function generates n random vectors, as rows of a matrix.
Examples
rprior <- rNormalPrior(c(-1,0,1),c(1,2,3))
C <- fitCopula(rprior(1000))
D <- rCopulaPrior(C)
print(cov(D(100)))
#> [,1] [,2] [,3]
#> [1,] 0.9957106 -0.14338268 0.22428630
#> [2,] -0.1433827 4.33235214 0.05887743
#> [3,] 0.2242863 0.05887743 8.23339658
print(D(10))
#> [,1] [,2] [,3]
#> [1,] 1.06838879 2.638188 1.8098286
#> [2,] -2.35551577 -1.417578 6.6220676
#> [3,] -0.39934949 1.837523 6.1432362
#> [4,] -0.02448666 2.180708 1.6167046
#> [5,] -1.70231310 -4.259623 9.7382009
#> [6,] -2.10083689 -2.001452 2.1109291
#> [7,] -1.44128057 -2.915991 1.9903715
#> [8,] -2.09558236 -1.572192 1.2180026
#> [9,] -0.70463374 -1.339199 0.9681756
#> [10,] 0.30752364 -2.965675 0.5547099