rUniformPrior returns a random vector generator
rUniformPrior.RdThe return value is a function that generates random vectors of the same size as ll and ul from a uniform distribution within the limits defined by ul and ll. The random vectors are returned as n rows of a matrix, where n is the only argument of the returned function.
Value
a uniform random vector generating function: runiform(n), where n is the requested number of vectors (rows)
Examples
rup<-rUniformPrior(ll=c(0,1,2),ul=c(1,2,3))
rup(12)
#> [,1] [,2] [,3]
#> [1,] 0.3386560 1.095910 2.413282
#> [2,] 0.5966007 1.345013 2.776037
#> [3,] 0.6240457 1.577476 2.225826
#> [4,] 0.4597298 1.394481 2.282954
#> [5,] 0.3514389 1.679138 2.314035
#> [6,] 0.7370885 1.426999 2.583404
#> [7,] 0.6091541 1.418145 2.773361
#> [8,] 0.1881191 1.258829 2.293717
#> [9,] 0.9364527 1.379097 2.891245
#> [10,] 0.4227039 1.285648 2.204261
#> [11,] 0.7462771 1.370115 2.636698
#> [12,] 0.7373561 1.960450 2.100753