Simple unit from string
simple.unit.RdThis function takes a simple, human readable unit (without '*' or '/'), from a string and returns a data.frame with the unit's meaning.
simple.unit.RdThis function takes a simple, human readable unit (without '*' or '/'), from a string and returns a data.frame with the unit's meaning.