Retrieve information about compiled code
so_path.RdReturns the path of the shared library (.so file). The model is typically a list of named arrays and matrices.
so_path.RdReturns the path of the shared library (.so file). The model is typically a list of named arrays and matrices.