Standard Error Matrix from an errors object
standard_error_matrix.RdIf a matrix has an errors attribute, it is usually a vector.
THis function returns the values of this attribute as a matrix (it
preserves the dimensions of the host matrix).
standard_error_matrix.RdIf a matrix has an errors attribute, it is usually a vector.
THis function returns the values of this attribute as a matrix (it
preserves the dimensions of the host matrix).