Standard Error Matrix from an errors object
standard_error_matrix.RdIf a matrix has an errors attribute, it is usually a vector.
THis function returns the values of this attribute as a matrix (it
preserves the dimensions of the host matrix).
Examples
M <- matrix(seq(12),3,4,dimnames=liest(letters[seq(3)],LETTERS[seq(4)]))
#> Error in liest(letters[seq(3)], LETTERS[seq(4)]): could not find function "liest"
errors(M) <- abs(M*0.1 + 0.1)
#> Error: object 'M' not found
E <- standard_error_matrix(M)
#> Error: object 'M' not found
print(E)
#> Error: object 'E' not found