Skip to contents

given a string describing a unit of measurement, this function prints the interpretation on screen, rather than returning it as a data.frame

Usage

unit.info(unit.str, unit = unit.from.string(unit.str))

Arguments

unit.str

unit string

unit

optionally, the data.frame that describes the unit

Examples