Prints an interpretation string of a unit
unit.info.Rdgiven a string describing a unit of measurement, this function prints the interpretation on screen, rather than returning it as a data.frame
Usage
unit.info(unit.str, unit = unit.from.string(unit.str))