Unit scale from SI prefix
unit.scale.RdThis function reads a prefix from a string and returns the exponent (base-10) that this prefix represents.
unit.scale.RdThis function reads a prefix from a string and returns the exponent (base-10) that this prefix represents.