Skip to contents

Given a data.frame this funciton retrieves the strings in the unit column named: unit, Unit, units (partial matching disregarding capitalization).

Usage

units_from_table(df, default = "1")

Arguments

df

a data.frame

default

default value if no unit column exists

Value

a character vector of units with names

Details

The returned value uses the row names of the data.frame as names of the character vector of units.