Updates the named values of vector v with values mentioned in data.frame d
update_values.RdGiven a named vector, this function will create a mtarix, with
several copies of the vector, with different values, dependeing on
some context. The context is each row of a data.frame, with
columns referring to the names of v, and values for the entries
in v for that row's context. Example: the rows can be different
experinemnts, with each experiment assigning new values to some
members of v (but not necessarily all).